stream property
Stream<T>
get
stream
The single-subscription stream that emits values from the other endpoint.
Implementation
Stream<T> get stream;
The single-subscription stream that emits values from the other endpoint.
Stream<T> get stream;